==> cyphermed-2.1.21-py3-none-any.whl: cyphermed/api/projects/delete_project_access_by_id.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.success import Success
from ...types import Response


def _get_kwargs(
    project_id: str,
    grantee_id: str,
) -> Dict[str, Any]:
    _kwargs: Dict[str, Any] = {
        "method": "delete",
        "url": f"/v2/projects/{project_id}/access/{grantee_id}",
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Success]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Success.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Success]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
) -> Response[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        grantee_id=grantee_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
) -> Optional[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return sync_detailed(
        project_id=project_id,
        grantee_id=grantee_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
) -> Response[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        grantee_id=grantee_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
) -> Optional[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            grantee_id=grantee_id,
            client=client,
        )
    ).parsed

==> cyphermed-2.2.0-py3-none-any.whl: cyphermed/api/projects/delete_project_access_by_id.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.success import Success
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: str,
    grantee_id: str,
    *,
    permanent: Union[Unset, bool] = True,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    params["permanent"] = permanent

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "delete",
        "url": f"/v2/projects/{project_id}/access/{grantee_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Success]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Success.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Success]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = True,
) -> Response[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):
        permanent (Union[Unset, bool]): If true, delete the project access permanently Default:
            True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        grantee_id=grantee_id,
        permanent=permanent,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = True,
) -> Optional[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):
        permanent (Union[Unset, bool]): If true, delete the project access permanently Default:
            True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return sync_detailed(
        project_id=project_id,
        grantee_id=grantee_id,
        client=client,
        permanent=permanent,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = True,
) -> Response[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):
        permanent (Union[Unset, bool]): If true, delete the project access permanently Default:
            True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        grantee_id=grantee_id,
        permanent=permanent,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    grantee_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = True,
) -> Optional[Success]:
    """Delete Project Access By Id

     Delete a project access by ID

    Args:
        project_id (str):
        grantee_id (str):
        permanent (Union[Unset, bool]): If true, delete the project access permanently Default:
            True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            grantee_id=grantee_id,
            client=client,
            permanent=permanent,
        )
    ).parsed
